@@ -1,7 +1,6 @@
 OC.L10N.register(
     "mail",
     {
-    "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
     "Important" : "Importante",
     "Work" : "Trabajo",
     "Personal" : "Personal",
@@ -24,7 +23,10 @@ OC.L10N.register(
     "Connecting" : "Conectando",
     "Save" : "Guardar",
     "Connect" : "Conectar",
+    "Password required" : "Contraseña requerida",
+    "Aliases" : "Aliases",
     "Signature" : "Firma",
+    "Go back" : "Regresar",
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
@@ -32,26 +34,25 @@ OC.L10N.register(
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
-    "Sending …" : "Enviando ...",
-    "Go back" : "Regresar",
-    "Retry" : "Reintentar",
-    "Message sent!" : "¡Mensaje enviado!",
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
+    "Confirm" : "Confirmar",
     "Unfavorite" : "Quitar favorito",
     "Favorite" : "Hacer favorito",
     "Read" : "Leer",
     "Select" : "Seleccionar",
     "Edit tags" : "Editar etiquetas",
-    "Move" : "Mover",
     "More actions" : "Más acciones",
+    "Back" : "Atrás",
+    "Forward" : "Adelante",
     "All day" : "Todo el día",
     "Create" : "Crear",
+    "Comment" : "Comentario",
+    "Accept" : "Aceptar",
+    "Decline" : "Declinar",
     "Choose" : "Seleccionar",
-    "Favorites" : "Favoritos",
     "Other" : "Otro",
     "Reply" : "Responder",
-    "Forward" : "Adelante",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
@@ -59,26 +60,40 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
-    "New message" : "Mensaje nuevo",
-    "Settings" : "Configuraciones ",
+    "Move" : "Mover",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
     "Mark all as read" : "Marcar todos como leídos",
     "Clear cache" : "Borrar el caché",
+    "New message" : "Mensaje nuevo",
+    "Refresh" : "Actualizar",
+    "Retry" : "Reintentar",
+    "Sending …" : "Enviando ...",
+    "Message" : "Mensaje",
     "Delete" : "Borrar",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
+    "Close" : "Cerrar",
+    "Tags" : "Etiquetas",
+    "Select tags" : "Selecciona las etiquetas",
+    "Search" : "Buscar",
+    "Date" : "Fecha",
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
     "Remove" : "Eliminar",
     "Reset" : "Restablecer",
+    "Client ID" : "ID del cliente",
+    "Client secret" : "Secreto del cliente",
     "General" : "General",
     "User" : "Usuario",
     "Host" : "Servidor",
     "Port" : "Puerto",
+    "Valid until" : "Válido hasta",
+    "Certificate" : "Certificado",
+    "Submit" : "Enviar",
     "Keyboard shortcut" : "Atajo del teclado",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
@@ -87,12 +102,11 @@ OC.L10N.register(
     "Older message" : "Mensaje más antiguo",
     "Toggle star" : "Alternar favoritos",
     "Toggle unread" : "Alternar no leídos",
-    "Search" : "Buscar",
-    "Refresh" : "Actualizar",
+    "Archive" : "Archivar",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
-    "Archive" : "Archivar",
     "Drafts" : "Borradores",
+    "Favorites" : "Favoritos",
     "All inboxes" : "Todos los buzones de entrada",
     "Inbox" : "Buzón de entrada",
     "Junk" : "Basura",
@@ -108,7 +122,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no quieres visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
     "Continue to %s" : "Continuar a %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
