@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Ívafin skilaboð %s",
     "Important mail" : "Mikilvægur póstur",
+    "No message found yet" : "Engin skilaboð hafa ennþá fundist",
+    "Set up an account" : "Setja upp notandaaðgang",
     "Unread mail" : "Ólesinn póstur",
     "Important" : "Mikilvægt",
     "Work" : "Vinna",
@@ -73,8 +75,6 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Veldu skrá til að setja sem viðhengi",
     "Choose a file to share as a link" : "Veldu skrá til að deila sem tengli",
     "Confirm" : "Staðfesta",
-    "No message found yet" : "Engin skilaboð hafa ennþá fundist",
-    "Set up an account" : "Setja upp notandaaðgang",
     "Plain text" : "Ósniðinn texti",
     "Rich text" : "Sniðinn texti",
     "No messages" : "Engin skilaboð",
@@ -111,7 +111,6 @@ OC.L10N.register(
     "Reply" : "Svara",
     "Reply to sender only" : "Svara einungis sendanda",
     "View source" : "Skoða frumkóða",
-    "Message source" : "Uppruni skilaboða",
     "Import into calendar" : "Flytja inn dagatal",
     "Download attachment" : "Sækja viðhengi",
     "Save to Files" : "Vista í skrár",
@@ -157,6 +156,7 @@ OC.L10N.register(
     "Copy to clipboard" : "Afrita á klippispjald",
     "Add" : "Bæta við",
     "Close" : "Loka",
+    "Body" : "Meginmál",
     "Tags" : "Merki",
     "Select tags" : "Veldu merki",
     "Clear" : "Hreinsa",
@@ -167,12 +167,14 @@ OC.L10N.register(
     "Custom" : "Sérsniðið",
     "Signature …" : "Undirskrift …",
     "Save signature" : "Vista undirskrift",
+    "Delete tag" : "Eyða merki",
     "Add tag" : "Bæta við merki",
     "Tag already exists" : "Merki er þegar til",
     "Not found" : "Fannst ekki",
     "Could not load your message thread" : "Gat ekki hlaðið inn skilaboðaþræðinum þínum",
     "Mark as unread" : "Merkja allt sem ólesið",
     "Mark as read" : "Merkja sem lesið",
+    "Message source" : "Uppruni skilaboða",
     "Remove" : "Fjarlægja",
     "(organizer)" : "(skipuleggjandi)",
     "Untitled event" : "Ónefndur atburður",
