@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Vstavljeno sporočilo %s",
     "Important mail" : "Pomembno sporočilo",
+    "No message found yet" : "Ni še najdenih sporočil",
+    "Set up an account" : "Nastavi račun",
     "Unread mail" : "Neprebrana pošta",
     "Important" : "Pomembno",
     "Work" : "Službeno",
@@ -84,6 +86,8 @@ OC.L10N.register(
     "Register as application for mail links" : "Nastavi kot program za odpiranje povezav na poštne elektronske naslove",
     "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
     "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME",
+    "Newest" : "Najnovejše",
+    "Oldest" : "Najstarejše",
     "Looking for a way to encrypt your emails?" : "Ali iščete način za šifriranje elektronskih sporočil?",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
     "Put my text to the bottom of a reply instead of on top of it." : "Dodaj besedilo odgovora pod izvorno sporočilo in ne nad.",
@@ -145,8 +149,6 @@ OC.L10N.register(
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Velikost priloge presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave."],
     "Untitled message" : "Nenaslovljeno sporočilo",
     "Confirm" : "Potrdi",
-    "No message found yet" : "Ni še najdenih sporočil",
-    "Set up an account" : "Nastavi račun",
     "Plain text" : "Besedilno",
     "Rich text" : "Obogateno besedilo",
     "No messages in this mailbox" : "V poštnem predalu ni sporočil.",
@@ -175,6 +177,10 @@ OC.L10N.register(
     "Download message" : "Prejmi sporočilo",
     "Blind copy recipients only" : "Le prejemniki skrite kopije",
     "No subject" : "Ni zadeve",
+    "Set reminder for later today" : "Nastavi opomnik za danes",
+    "Set reminder for tomorrow" : "Nastavi opomnik za jutri",
+    "Set reminder for this weekend" : "Nastavi opomnik za ta teden",
+    "Set reminder for next week" : "Nastavi opomnik za naslednji teden",
     "No trash mailbox configured" : "Ni nastavljenega poštne mape za smeti",
     "Could not delete message" : "Sporočila ni mogoče izbrisati",
     "Could not archive message" : "Ni mogoče arhivirati sporočila",
@@ -232,13 +238,13 @@ OC.L10N.register(
     "Forward message as attachment" : "Posreduj sporočilo kot prilogo",
     "View source" : "Pokaži kode sporočila",
     "Download thread data for debugging" : "Prejmi podatke niti za razhroščevanje",
-    "Message source" : "Vir sporočila",
     "Message body" : "Telo sporočila",
     "Import into calendar" : "Uvozi v koledar",
     "Download attachment" : "Prejmi prilogo",
     "Save to Files" : "Shrani v Datoteke",
     "Unnamed" : "Neimenovano",
     "Embedded message" : "Vstavljeno sporočilo",
+    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
     "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje priloge",
     "View fewer attachments" : "Pokaži manj prilog",
     "Save all to Files" : "Shrani vse v Datoteke",
@@ -329,7 +335,7 @@ OC.L10N.register(
     "Search in mailbox" : "Preišči poštni predal",
     "Close" : "Zapri",
     "Search parameters" : "Poišči parametre",
-    "Search term" : "Poišči izraz",
+    "Body" : "Besedilo",
     "Pick a start date" : "Izbor datuma začetka",
     "Pick an end date" : "Izbor datuma konca",
     "Select senders" : "Izbor pošiljateljev",
@@ -356,21 +362,22 @@ OC.L10N.register(
     "Save sieve settings" : "Shrani nastavitve sieve",
     "Save sieve script" : "Shrani skript sieve",
     "The syntax seems to be incorrect:" : "Skladnja je videti nepravilna:",
+    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
     "Signature …" : "Podpis ...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Nastavljen podpis je večji od 2 MB. Velikost lahko vpliva na delovanje urejevalnika.",
     "Save signature" : "Shrani podpis",
     "Place signature above quoted text" : "Postavi podpis nad navedeno besedilo.",
-    "Add default tags" : "Dodaj privzete oznake",
-    "Rename tag" : "Preimenuj oznako",
+    "Delete tag" : "Izbriši oznako",
     "Saving new tag name …" : "Poteka shranjevanje imena oznake ...",
     "Set tag" : "Nastavi oznako",
     "Unset tag" : "Odstrani oznako",
+    "An error occurred, unable to rename the tag." : "Prišlo je do napake, oznake ni mogoče preimenovati.",
+    "Add default tags" : "Dodaj privzete oznake",
     "Add tag" : "Dodaj oznako",
     "Saving tag …" : "Poteka shranjevanje ozake ...",
     "Tag name is a hidden system tag" : "Ime oznake je skrita sistemska oznaka",
     "Tag already exists" : "Oznaka že obstaja",
     "An error occurred, unable to create the tag." : "Prišlo je do napake, oznake ni mogoče ustvariti.",
-    "An error occurred, unable to rename the tag." : "Prišlo je do napake, oznake ni mogoče preimenovati.",
     "Select calendar" : "Izbor koledarja",
     "No calendars with task list support" : "Koledar s podporo seznama nalog",
     "Task created" : "Naloga je ustvarjena",
@@ -386,6 +393,7 @@ OC.L10N.register(
     "Mark as read" : "Označi kot prebrano",
     "Archive message" : "Arhiviraj sporočilo",
     "Delete message" : "Izbriši sporočilo",
+    "Message source" : "Vir sporočila",
     "Encrypted & verified " : "Šifrirano in overjeno",
     "Signature verified" : "Podpis je overjen",
     "Signature unverified " : "Podpis ni overjen",
@@ -481,6 +489,8 @@ OC.L10N.register(
     "Archive" : "Arhiv",
     "Account connected" : "Račun je povezan",
     "Connect your mail account" : "Povežite svoj elektronski račun",
+    "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
+    "Later today – {timeLocale}" : "Danes – {timeLocale}",
     "Itinerary for {type} is not supported yet" : "{type} – vrsta prevoza še ni podprta",
     "All" : "Vse",
     "Drafts" : "Osnutki",
