@@ -15,16 +15,19 @@ OC.L10N.register(
     "Save" : "บันทึก",
     "Connect" : "เชื่อมต่อ",
     "Signature" : "ลายเซ็น",
+    "Go back" : "กลับไป",
     "Change name" : "เปลี่ยนชื่อ",
     "Email address" : "ที่อยู่อีเมล",
     "Cancel" : "ยกเลิก",
     "Send" : "ส่ง",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
+    "Confirm" : "ยืนยัน",
     "Favorite" : "รายการโปรด",
     "Read" : "อ่าน",
     "Unselect" : "ยกเลิกการเลือก",
     "Select" : "เลือก",
     "Edit tags" : "แก้ไขแท็ก",
+    "Back" : "ย้อนกลับ",
     "Forward" : "ส่งต่อ",
     "Create" : "สร้าง",
     "Comment" : "ความคิดเห็น",
@@ -42,11 +45,12 @@ OC.L10N.register(
     "Remove account" : "ลบบัญชี",
     "Mark all as read" : "เปลี่ยนทั้งหมดเป็นอ่านแล้ว",
     "Clear cache" : "ล้างแคช",
-    "Go back" : "กลับไป",
+    "Refresh" : "รีเฟรช",
     "Sending …" : "กำลังส่ง ...",
     "Delete" : "ลบ",
     "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
     "Add" : "เพิ่ม",
+    "Close" : "ปิด",
     "Tags" : "แท็ก",
     "Clear" : "ล้าง",
     "Search" : "ค้นหา",
@@ -65,12 +69,10 @@ OC.L10N.register(
     "Port" : "พอร์ต",
     "Valid until" : "ใช้ได้จนถึง",
     "Certificate" : "ใบรับรอง",
-    "Back" : "ย้อนกลับ",
     "Submit" : "ส่ง",
     "Keyboard shortcut" : "แป้นพิมพ์ลัด",
     "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
     "Archive" : "ที่เก็บถาวร",
-    "Refresh" : "รีเฟรช",
     "Account connected" : "เชื่อมต่อบัญชีแล้ว",
     "All" : "ทั้งหมด",
     "Drafts" : "ฉบับร่าง",
