@@ -84,7 +84,6 @@ class ThreadBuilder {
 		$idTable = [];
 
 		foreach ($messages as $message) {
-			/** @var Message $message */
 			// Step 1.A
 			$container = $idTable[$message->getId()] ?? null;
 			if ($container !== null && !$container->hasMessage()) {
@@ -127,7 +126,7 @@ class ThreadBuilder {
 	 */
 	private function buildRootContainer(array $idTable): Container {
 		$rootContainer = Container::empty();
-		foreach ($idTable as $id => $container) {
+		foreach ($idTable as $container) {
 			if (!$container->hasParent()) {
 				$container->setParent($rootContainer);
 			}
@@ -135,12 +134,8 @@ class ThreadBuilder {
 		return $rootContainer;
 	}
 
-	/**
-	 * @param Container $container
-	 */
 	private function pruneContainers(Container $root): void {
-		/** @var Container $container */
-		foreach ($root->getChildren() as $id => $container) {
+		foreach ($root->getChildren() as $container) {
 			// Step 4.A
 			if (!$container->hasMessage() && !$container->hasChildren()) {
 				$container->unlink();
