@@ -50,7 +50,7 @@ class AutoCompleteService {
 		$fromCollector = $this->addressCollector->searchAddress($userId, $term);
 
 		// Convert collected addresses into same format as CI creates
-		$recipientsFromCollector = array_map(function (CollectedAddress $address) {
+		$recipientsFromCollector = array_map(static function (CollectedAddress $address) {
 			return [
 				'id' => $address->getId(),
 				'label' => $address->getDisplayName(),
