@@ -97,7 +97,7 @@ class Favicon
         $loop = true;
         while ($loop && $max_loop-- > 0) {
             $headers = $this->dataAccess->retrieveHeader($url);
-            if (empty($headers) || !array_key_exists(0, $headers)) {
+            if (empty($headers) || !is_array($headers) || !array_key_exists(0, $headers)) {
                 return false;
             }
             $exploded = explode(' ', $headers[0]);
@@ -110,9 +110,13 @@ class Favicon
             switch ($status) {
                 case '301':
                 case '302':
-                    $url = isset($headers['location']) ? $headers['location'] : '';
-                    if (is_array($url)) {
-                        $url = end($url);
+                    if (isset($headers['location'])) {
+                        $url = $headers['location'];
+                        if (is_array($url)) {
+                            $url = end($url);
+                        }
+                    } else {
+                        return false;
                     }
                     break;
                 default:
@@ -148,9 +152,9 @@ class Favicon
             $this->url = $url;
         }
 
-        // Get the base URL without the path for clearer concatenations.
         $url = rtrim($this->baseUrl($this->url, true), '/');
         $original = $url;
+
         if (
             ($favicon = $this->checkCache($original, self::$TYPE_CACHE_URL)) === false
             && ! $favicon = $this->getFavicon($original, false)
@@ -208,7 +212,12 @@ class Favicon
 
         // Make sure the favicon is an absolute URL.
         if ($favicon && filter_var($favicon, FILTER_VALIDATE_URL) === false) {
-            $favicon = rtrim($url, '/') . '/' . ltrim($favicon, '/');
+            // Make sure that favicons starting with "/" get concatenated with host instead of full URL
+            if ($favicon[0] === '/') {
+                $favicon = $this->baseUrl($url) . ltrim($favicon, '/');
+            } else {
+                $favicon = rtrim($url, '/') . '/' . ltrim($favicon, '/');
+            }
         }
 
         // Sometimes people lie, so check the status.
@@ -398,7 +407,7 @@ class Favicon
     }
 
     /**
-     * @param DataAccess|\PHPUnit_Framework_MockObject_MockObject $dataAccess
+     * @param DataAccess $dataAccess
      */
     public function setDataAccess($dataAccess)
     {
